/* format.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"
#include "format.h"

#include <stdio.h>
#include <math.h>

static const char *month_names[12] = {
  "January", "February", "March", "April", "May", "June",
  "July", "August", "September", "October", "November", "December",
};

string 
format_elapsed_time(double seconds) {
  int isec = (int)floor(seconds + 0.5);
  char time_str[128];
  sprintf(time_str, "%d:%02d", isec / 60, isec % 60);
  return string(time_str);
}

string
format_int(int num) {
  char num_str[128];
  sprintf(num_str, "%d", num);
  return string(num_str);
}

string
format_float(double num) {
  char num_str[128];
  sprintf(num_str, "%f", num);
  return string(num_str);
}

string
format_date(time_t time_value) {
  struct tm *time = localtime(&time_value);

  char date_str[128];
  sprintf(date_str, "%s %d, %d",
	  month_names[time->tm_mon], time->tm_mday, time->tm_year + 1900);
  return date_str;
}

string
format_datetime(time_t time_value) {
  struct tm *time = localtime(&time_value);

  int hour12 = time->tm_hour;
  const char *ampm = "am";
  if (hour12 == 0) {
    hour12 = 12;
  } else if (hour12 == 12) {
    ampm = "pm";
  } else if (hour12 > 12) {
    hour12 -= 12;
    ampm = "pm";
  }

  char date_str[128];
  sprintf(date_str, "%s %d, %d at %d:%d %s",
	  month_names[time->tm_mon], time->tm_mday, time->tm_year + 1900,
	  hour12, time->tm_min, ampm);
  return date_str;
}

