/* formWidget.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef FORMWIDGET_H
#define FORMWIDGET_H

#include "tableInfo.h"
#include "dataCell.h"

#include <gtk--.h>

class Dataset;
class DataCell;
class Form;
class RatioSliderGroup;

class FormWidget {
public:
  // New types must always be added to the end of this enumerated type
  // definition; since the numeric values of the enum are stored in
  // the database, we can't afford to change any of the
  // previously-defined values.
  enum Type {
    T_label,
    T_check_box,
    T_ratio_group,
    T_number,
    T_year,
    T_string,
    T_text,
    T_combo_box,
    T_artist,
  };

  static DataCell::Type get_db_type(Type &type);
  static TableID get_foreign_table(Type &type);

  class Instance {
  public:
    Instance(Gtk_Widget *widget, DataCell *cell, const FormWidget *def);
    void update(Form *form);
    static void update_ratio_group(Form *form, RatioSliderGroup *group);

    DataCell get_value() const;

    Gtk_Widget *_widget;
    DataCell *_cell;
    const FormWidget *_def;
  };

  FormWidget();

  Type get_type() const;
  int get_type_assoc() const;
  const string &get_internal_name() const;

  int insert_db(int form_id);
  Instance make_instance(Dataset *data) const;

private:  
  RatioSliderGroup *make_ratio_group(int widget_id) const;

public:  
  int _widget_id;
  TableID _table_id;
  int _field_id;
  Type _widget_type;
  int _type_assoc;
  string _internal_name;
  string _label;
  int _place_left;
  int _place_right;
  int _place_top;
  int _place_bottom;
  int _xoptions;
  int _yoptions;
  int _xpadding;
  int _ypadding;
  int _uxsize;
  int _uysize;
};

#endif
