/* tableDef.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef TABLEDEF_H
#define TABLEDEF_H

#include "dataCell.h"
#include "tableField.h"

#include <map>

class TableDef {
public:
  TableDef();
  ~TableDef();

  static const TableDef *get_table(TableID table_id);
  static const TableDef *reread_table(TableID table_id);

  void record_db();
  bool look_up(TableID table_id);
  const TableField &get_field(int field_id) const;

  static const TableField *find_any_field(const string &name);

  void define_pkey(const string &field_name, const string &label);
  void define_field(int field_id, DataCell::Type field_type, 
		    TableID foreign_table, const DataCell &default_value,
		    const string &field_name, const string &label);


  // Mapping field_id to TableField.
  typedef map<int, TableField> Fields;
  Fields _fields;

  // This is a static map of all the tables in the universe.  We keep
  // it so we only have to generate the definition for each table
  // once.
  typedef map<TableID, TableDef *> TableDefs;
  static TableDefs _table_defs;

  // We also have a static map of all the fields in the universe, by
  // field name.  This is mainly handy for guessing the intended type
  // of a column based on its name.
  typedef map<string, TableField> FieldsByName;
  static FieldsByName _all_fields_by_name;

  TableID _table_id;
};
    
#endif
